"""Creates a version of traceback.rst to insert in the documentation.

This assumes that such a file already exist; this is only done to
ensure we have the right destination. If so, we actually rewrite it.

"""

import os
import sys
import platform
from contextlib import redirect_stdout


# Make it possible to find avantpy and docs source
this_dir = os.path.dirname(__file__)
root_dir = os.path.abspath(os.path.join(this_dir, "..", ".."))
sys.path.insert(0, this_dir)
sys.path.insert(0, root_dir)


import avantpy  # sets up import hook


target = os.path.normpath(os.path.join(root_dir, "docs/source/tracebacks.rst"))


try:
    assert os.path.isfile(target)
except AssertionError:
    print("Wrong path: traceback.rst does not exist.")
    sys.exit()


content = """Friendly error messages
=======================

AvantPy aims to provide friendlier feedback when an exception
is raised than what is done by Python.
Such feedback will also be available in languages other than English.

.. note::

     The content of this file is generated by running
     tb_pyupper.py located in the ``tests/pyupper/`` directory.
     This needs to be done explicitly, independently of updating the
     documentation using Sphinx.

AvantPy version: {avantpy}
Python version: {python}

""".format(
    avantpy=avantpy.version.__version__, python=platform.python_version()
)


def make_title(text):
    print()
    print(text)
    print("-" * len(text), "\n")
    print("Example::\n")


def create_tracebacks():
    with open(target, "w") as out:
        with redirect_stdout(out):
            print(content)

            make_title("IfNobreakError")
            import raise_if_nobreak

            make_title("MismatchedBracketsError")
            import raise_mismatched_brackets

            make_title("MissingLeftBracketError")
            import raise_missing_left_bracket

            make_title("MissingRepeatError")
            import raise_missing_repeat

            print("\nExample 2::")
            import raise_missing_repeat2

            make_title("NobreakFirstError")
            import raise_nobreak_first

            make_title("NobreakSyntaxError")
            import raise_nobreak_syntax

            make_title("RepeatFirstError")
            import raise_repeat_first

            make_title("TryNobreakError")
            import raise_try_nobreak

            make_title("UnknownLanguageError")
            import raise_unknown_language

            make_title("UnknownDialectError")
            import raise_unknown_dialect

            make_title("UnexpectedError")
            print("    No example found yet.\n")


try:
    create_tracebacks()
except ImportError:
    print("ImportError: please try running this program from it location using")
    print("             python tb_pyupper.py")
